==> haskell-tagstream-conduit-0.5.5.3-65-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-AKVje3f3O7ZBHUkCl33TNk
key: tagstream-conduit-0.5.5.3-AKVje3f3O7ZBHUkCl33TNk
license: BSD3
maintainer: yi.codeplayer@gmail.com
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
author: yihuang
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Text Text.HTML.TagStream.Types
    Text.HTML.TagStream.Utils Text.HTML.TagStream.Entities
abi: e14f189d78bf619f8edb883a4ad5bd67
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-AKVje3f3O7ZBHUkCl33TNk
depends:
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-conduit-1.4.0.4-4JMNsrmqa8CJ6lSm2Ik1gQ
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.5.3-76-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-KFRapTykI6m1nTRcOtYAUa
key: tagstream-conduit-0.5.5.3-KFRapTykI6m1nTRcOtYAUa
license: BSD3
maintainer: yi.codeplayer@gmail.com
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
author: yihuang
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Text Text.HTML.TagStream.Types
    Text.HTML.TagStream.Utils Text.HTML.TagStream.Entities
abi: cf677c14ae3d4ba708fc7704b34fe85e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-KFRapTykI6m1nTRcOtYAUa
depends:
    attoparsec-0.13.1.0-oc29svN3SiFq1TojBIbwV base-4.9.0.0
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
    conduit-1.2.11-67QBPVFU7Mu9oEC9xc41Cq
    conduit-extra-1.1.16-848Xd70hoN45Ueua8FUxsp
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    resourcet-1.1.9-4wjmwiYhI4Y4ny0clYPjM8
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v transformers-0.5.2.0
    xml-conduit-1.4.0.4-CBbPBLXH55v2v1vIALQiH4
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
